{%- from "octavia/map.jinja" import api with context %}

{%- if api.enabled %}

include:
  {%- if pillar.get('apache', {}).get('server', {}).get('site', {}).octavia_api is defined %}
  - apache
  {%- endif %}
  - octavia.db.offline_sync
  - octavia._ssl.mysql
  - octavia._ssl.rabbitmq

octavia_api_packages:
  pkg.installed:
  - names: {{ api.pkgs }}
  - require_in:
    - sls: octavia.db.offline_sync
    - sls: octavia._ssl.mysql
    - sls: octavia._ssl.rabbitmq


/etc/octavia/octavia_api.conf:
  file.managed:
  - source: salt://octavia/files/{{ api.version }}/octavia_api.conf
  - template: jinja
  - require:
    - pkg: octavia_api_packages
    - sls: octavia._ssl.mysql
    - sls: octavia._ssl.rabbitmq
  - require_in:
    - sls: octavia.db.offline_sync

/etc/octavia/{{ api.get('oslo_policy', {}).get('policy_file', 'policy.json') }}:
  file.managed:
    - mode: 0640
    - replace: False
    - user: octavia
    - group: octavia
    - require:
      - pkg: octavia_api_packages

{%- for name, rule in api.get('policy', {}).iteritems() %}

{%- if rule != None %}
octavia_keystone_rule_{{ name }}_present:
  keystone_policy.rule_present:
  - path: /etc/octavia/{{ api.get('oslo_policy', {}).get('policy_file', 'policy.json') }}
  - name: '{{ name }}'
  - rule: '{{ rule }}'
  - require:
    - pkg: octavia_api_packages
    - file: /etc/octavia/{{ api.get('oslo_policy', {}).get('policy_file', 'policy.json') }}

{%- else %}

octavia_keystone_rule_{{ name }}_absent:
  keystone_policy.rule_absent:
  - path: /etc/octavia/{{ api.get('oslo_policy', {}).get('policy_file', 'policy.json') }}
  - name: '{{ name }}'
  - require:
    - pkg: octavia_api_packages
    - file: /etc/octavia/{{ api.get('oslo_policy', {}).get('policy_file', 'policy.json') }}

{%- endif %}

{%- endfor %}

{%- if pillar.octavia.manager is not defined %}
/etc/octavia/dhcp/:
  file.directory:
    - name: /etc/octavia/dhcp/
    - user: octavia
    - group: octavia
    - makedirs: true

/etc/octavia/dhcp/dhclient.conf:
  file.managed:
  - source: salt://octavia/files/{{ api.version }}/dhcp/dhclient.conf
  - require:
    - pkg: octavia_api_packages
{%- endif %}

{%- if not grains.get('noservices', False) %}
  {%- if pillar.get('apache', {}).get('server', {}).get('site', {}).octavia_api is not defined %}
octavia_api_services:
  service.running:
  - names: {{ api.services }}
  - enable: true
  - watch:
    - file: /etc/octavia/octavia_api.conf
  - require:
    - sls: octavia.db.offline_sync
    - sls: octavia._ssl.mysql
    - sls: octavia._ssl.rabbitmq
  {%- else %}
{# WA to point WSGI process on actual config file #}
octavia_conf_symlink:
  file.symlink:
    - name: /etc/octavia/octavia.conf
    - target: /etc/octavia/octavia_api.conf
    - backupname: /etc/octavia/octavia.conf.backup
    - force: true
    - require:
      - file: /etc/octavia/octavia_api.conf

octavia_api_services:
  service.dead:
  - names: {{ api.services }}
  - enable: false
  - require:
    - pkg: octavia_api_packages

octavia_api_apache_conf_file:
  file.exists:
  - names:
    - /etc/apache2/sites-available/wsgi_octavia_api.conf
  - require:
    - sls: apache.server.site
    - pkg: octavia_api_packages

apache_enable_octavia_api_wsgi:
  apache_site.enabled:
    - name: wsgi_octavia_api
    - require:
      - file: octavia_api_apache_conf_file
      - service: octavia_api_services
      - file: octavia_conf_symlink
    - watch_in:
      - service: apache_service
  {%- endif %}
{%- endif %}

{%- endif %}
